#! /usr/bin/env python

from __future__ import print_function

"""
Script that uses the CLI module to display all accounts within a domain, a list
of domains, or all domains.
"""
if __name__=='__main__':
  import sys
  try:
    import cli2
  except ImportError:
    print('ERROR: AXIGEN CLI Module could not be imported.', file=sys.stderr)
    print('Please place cli2.py in one of the following directories:', file=sys.stderr)
    for x in sys.path:
      print('-',x, file=sys.stderr)
    sys.exit(1)

  def show_help():
    print("""
Basic usage:
  %s kav=0|1 kas=0|1 status=0|1 [host=<cli host>] \\
    [port=<cli port>] [s=0|1] \\
    [pass=<admin password>] [domains=domain1[,domain2[,...]]]

  Where, each parameter is:
  kav	   - Update Kaspersky AntiVirus
  kas      - Update Kaspersky Antispam
  host     - CLI host to connect to; default: localhost
  port     - CLI port to connect ro; default: 7000
  pass     - if specified, will use this password, otherwise will ask for one
  s	   - supress output, enabled by default 
	     Useful when running the script in CRONTAB.
  status   - print status of databases and exit

  Examples of usage
  - update KAV
  %s kav=1 host=192.168.102.24 port=7001
 
  - update KAS
  %s kas=1

  - update KAV and KAS
  %s kav=1 kas=1

  - suppress the output, the script will not echo any output
  %s s=0

  - only print the status of the databases and exit
  %s status=1

  """ % (sys.argv[0], sys.argv[0], sys.argv[0], sys.argv[0], sys.argv[0], sys.argv[0]), file=sys.stderr)

# defaults
  cliHost=None
  cliPort=None
  cliUser=None
  cliPass=None
  kav="0"
  kas="0"
  status="0"
  s="1"


  for param in sys.argv[1:]:
    if param.startswith('host='):
      cliHost=param[5:]
      continue
    if param.startswith('port='):
      cliPort=param[5:]
      continue
    if param.startswith('user='):
      cliUser=param[5:]
      continue
    if param.startswith('pass='):
      cliPass=param[5:]
      continue
    if param.startswith('kav='):
      kav=param[4:]
      continue
    if param.startswith('kas='):
      kas=param[4:]
      continue
    if param.startswith('s='):
      s=param[2:]
      continue
    if param.startswith('status='):
      status=param[7:]
      continue
  
  if kav!="0":
    kav=True
  else:
    kav=False
  if kas!="0":
    kas=True
  else:
    kas=False
  if status!="0":
    status=True
  else:
    status=False
  if s!="0":
    s=True
  else:
    s=False
  
  if cliHost==None:
    cliHost="127.0.0.1"
  if cliPort==None:
    cliPort="7000"
  if cliUser==None:
    cliUser="admin"
  if not cliPort.isdigit():
    print("Port must be a number", file=sys.stderr)
    sys.exit(1)
  cliPort=int(cliPort)

  if (not status): 
    if ( (not kav) and (not kas) ):
      print("KAV or KAS not specified", file=sys.stderr)
      show_help()
      sys.exit(1)

  if s: print('Connecting to: %s:%s as %s' % (cliHost, cliPort, cliUser))

  c=cli2.CLI(cliHost, cliPort)
  if not cliPass:
    import getpass
    while not cliPass:
      cliPass=getpass.getpass('Enter CLI Admin password: ')
      if not cliPass:
        print('Empty passwords are not allowed!', file=sys.stderr)


##Uncomment if you want to enable debug:
#  cli2.CLI.debug=1

  c.auth(cliPass, cliUser)
  
  c.config_server()
  c.config_filters()

  if kas:  
    if s: print('\r\nSwitching to Kaspesky AS context...')
    c.update_kas()
    if s: print('Update database...')
    c.update_kav_kas_db()
    if s: print('\r\nKAS INFO: \r\n')
    kasinfo = c.getShowDatabaseUpdateStatusKAS()
    if s: 
      for i in kasinfo:
        print('\t%s' % i)
    c.done()
  
  if kav:
    if s: print('\r\nSwitching to Kaspesky AV context...')
    c.update_kav()
    if s: print('Update database...')
    c.update_kav_kas_db()
    if s: print('\r\nKAV INFO: \r\n')
    kavinfo = c.getShowDatabaseUpdateStatusKAV()
    if s: 
      for i in kavinfo:
        print('\t%s' % i)
    c.done(); 

  if status: 
    if s: print('\r\nKAV INFO: \r\n')
    kavinfo = c.getShowDatabaseUpdateStatusKAV()
    if s:
      for i in kavinfo:
        print('\t%s' % i)
    c.done()
    if s: print('\r\nKAS INFO: \r\n')
    kasinfo = c.getShowDatabaseUpdateStatusKAS()
    if s:
      for i in kasinfo:
        print('\t%s' % i)
    c.done()

